@@ -19,6 +19,7 @@ import tempfile
 
 import click
 from LbAPCommon import render_yaml, parse_yaml, validate_yaml
+from LbAPCommon.hacks import project_uses_cmt
 import requests
 
 from . import cern_sso
@@ -40,15 +41,16 @@ def prepare_test(production_name, job_name):
     try:
         job_data = prod_data[job_name]
     except KeyError:
-        click.ClickException(
+        raise click.ClickException(
             f"Job {job_name} is not found for production {production_name}!"
         )
 
-    dynamic_dir, out_dir = create_output_dir(production_name)
-
     application_name, application_version = job_data["application"].rsplit("/", 1)
     options = [*job_data["options"]]
 
+    require_cmt = project_uses_cmt(application_name, application_version)
+    dynamic_dir, out_dir = create_output_dir(production_name, require_cmt)
+
     if "bk_query" not in job_data["input"]:
         raise NotImplementedError("Currently only support bookkeeping inputs")
     params = {
@@ -56,6 +58,8 @@ def prepare_test(production_name, job_name):
         "application_version": application_version,
         "bk_query": job_data["input"]["bk_query"],
     }
+    if job_data.get("turbo") is not None:
+        params["turbo"] = job_data["turbo"]
     data = cern_sso.get_with_cookies(
         urlunparse(ANA_PROD_WEB_URL + ("", urlencode(params), ""))
     )
@@ -129,7 +133,9 @@ def prepare_reproduce(pipeline_id, production_name, job_name, test_id="latest"):
 
     check_production(production_name)
 
-    dynamic_dir, out_dir = create_output_dir(production_name)
+    app_name, app_version = data["env-command"][-1].rsplit("/", 1)
+    require_cmt = project_uses_cmt(app_name, app_version)
+    dynamic_dir, out_dir = create_output_dir(production_name, require_cmt)
 
     # Write the dynamic option files
     for filename, filecontent in data["dynamic_options"].items():
