@@ -17,6 +17,7 @@ import tempfile
 
 import click
 from LbAPCommon import write_jsroot_compression_options
+from LbAPCommon.hacks import setup_lbrun_environment
 
 
 def validate_environment():
@@ -95,7 +96,7 @@ def check_production(production_name):
         )
 
 
-def create_output_dir(production_name):
+def create_output_dir(production_name, require_cmt):
     """Create the directory structure for testing locally"""
 
     from datetime import datetime
@@ -123,14 +124,7 @@ def create_output_dir(production_name):
 
     # Create the fake install directory for lb-run
     click.secho(f"Setting CMAKE_PREFIX_PATH to {testing_dir}", fg="green")
-    os.environ["CMAKE_PREFIX_PATH"] = testing_dir
-    fake_install_dir = join(
-        testing_dir, "DBASE", "AnalysisProductions", "v999999999999"
-    )
-    os.makedirs(dirname(fake_install_dir), exist_ok=True)
-    if os.path.exists(fake_install_dir):
-        os.unlink(fake_install_dir)
-    os.symlink(os.getcwd(), fake_install_dir)
+    setup_lbrun_environment(testing_dir, os.getcwd(), require_cmt)
 
     return dynamic_dir, out_dir
 
@@ -158,3 +152,7 @@ def logging_subprocess_run(args, *, cwd=None):
             stdout = stdout.result()
             stderr = stderr.result()
     return subprocess.CompletedProcess(args, p.returncode, stdout, stderr)
+
+
+def production_name_type(production_name):
+    return production_name.strip("/")
